@@ -8,6 +8,8 @@ from .helpers.micro_fetcher import MicroFetcher
 from .helpers.atomic_transactions import Transactions
 from .helpers.auth import Auth
 from .helpers.enums import Service
+from .helpers.database.base_model import init_base_model
+from .helpers.database.log_model import init_log_model
 
 __all__ = [
     "WeDeliverCore",
@@ -20,4 +22,6 @@ __all__ = [
     "Transactions",
     "Service",
     "Auth",
+    "init_base_model",
+    "init_log_model",
 ]
