@@ -1,5 +1,5 @@
 import re
-from wedeliver_core.wedeliver_core.helpers.get_country_code import get_country_code
+from wedeliver_core.helpers.get_country_code import get_country_code
 
 
 def validate_mobile_number(mobile):
